Add information on cabinets, elections and parties to dataset. This data is obtained from ParlGov (http://www.parlgov.org/).
Source:R/addInfo.R
addInfo.RdAdd information on cabinets, elections and parties to dataset. This data is obtained from ParlGov (http://www.parlgov.org/).
Usage
addInfo(x, ...)
# S3 method for class 'voteList'
addInfo(x, ...)
# S3 method for class 'questionList'
addInfo(x, ...)