Add information on party characteristics to voteList or questionerList object. This data is obtained from ParlGov (http://www.parlgov.org/).
Source:R/addInfo.R
addPartyInfo.RdAdd information on party characteristics to voteList or questionerList object. This data is obtained from ParlGov (http://www.parlgov.org/).
Arguments
- x
A voteList object
- ...
Other parameters passed on.
- includetype
A charcter value, "basic" or "all". Defaults to "basic". Basic only includes party characteristics that vary by date, while all includes all party characteristics.
- addto
Character vector including the subtables to which party information should be added. Defaults to c("voteList", "sponsorList","votePerParty") vote a voteList object or c("questionerList", "responderList") for a questionList object.